fast-feedback virtual target task code on STM Nucleo

Dependencies:   mbed

Revision:
32:1416e015016c
Parent:
31:b320ca61a8c0
diff -r b320ca61a8c0 -r 1416e015016c task.h
--- a/task.h	Sun Oct 14 14:45:02 2018 +0000
+++ b/task.h	Thu Dec 13 07:18:43 2018 +0000
@@ -12,13 +12,13 @@
 #define CMD_CLEAR_INDEX     'O'
 #define CMD_EXECUTE         'X'
 
-#define CFG_DELAY_MIN       'm', (3000)
+#define CFG_DELAY_MIN       'm', (1000)
 #define CFG_DELAY_VAR       'd', (3000)
-#define CFG_PREP_DUR        'p', (1500)
+#define CFG_PREP_DUR        'p', (500)
 #define CFG_AUD_DUR         'a', (5000)
 #define CFG_AUD_FREQ        'f', (4)
-#define CFG_RESP_DUR        'y', (1000)
-#define CFG_POST_DUR        'n', (4000)
+#define CFG_RESP_DUR        'y', (1500)
+#define CFG_POST_DUR        'n', (3000)
 #define CFG_REWARD_DUR      'r', (50)
 #define CFG_ONSET_MIN       'o', (500)
 #define CFG_ONSET_STEPS     's', (10)
@@ -28,8 +28,9 @@
 #define CFG_LICK_DEBOUNCE   'l', (80)
 
 enum Mode {
-    Condition,
+    Pair,
     Report,
+    Stage,
     Associate,
     Motion,
     MotionAlt
@@ -38,7 +39,8 @@
 struct ModeSelection: public config::CommandResponder
 {
     static const char CMD_ID_MODE;
-    static const char CMD_MODE_CONDITION;
+    static const char CMD_MODE_PAIR;
+    static const char CMD_MODE_STAGE;
     static const char CMD_MODE_REPORT;
     static const char CMD_MODE_ASSOCIATE;
     static const char CMD_MODE_MOTION;
@@ -89,7 +91,7 @@
     
     Property<uint16_t>  vis_dur_ms;     // the duration for the (passive) visual cue.
     
-    Property<uint16_t>  vis_test_every;     // the frequency of 'test' trials during the Condition mode.
+    Property<uint16_t>  vis_test_every;     // the frequency of 'test' trials during the Pair/Report modes.
     
     Property<uint16_t>  whisk_debounce_ms;  // the debounce period for whisking events.
     
@@ -101,7 +103,7 @@
     
     Action              run;
     
-    explicit Task(const Mode& mode=Condition);
+    explicit Task(const Mode& mode=Pair);
     
     void parseFromSerial();